@@ -42,6 +42,8 @@ impl BinaryOffsetSizeTrait for i64 {
     const DATA_TYPE: DataType = DataType::LargeBinary;
 }
 
+/// See [`BinaryArray`] and [`LargeBinaryArray`] for storing
+/// binary data.
 pub struct GenericBinaryArray<OffsetSize: BinaryOffsetSizeTrait> {
     data: ArrayData,
     value_offsets: RawPtrBox<OffsetSize>,
@@ -174,7 +176,7 @@ impl<OffsetSize: BinaryOffsetSizeTrait> GenericBinaryArray<OffsetSize> {
 impl<'a, T: BinaryOffsetSizeTrait> GenericBinaryArray<T> {
     /// constructs a new iterator
     pub fn iter(&'a self) -> GenericBinaryIter<'a, T> {
-        GenericBinaryIter::<'a, T>::new(&self)
+        GenericBinaryIter::<'a, T>::new(self)
     }
 }
 
@@ -191,7 +193,7 @@ impl<OffsetSize: BinaryOffsetSizeTrait> fmt::Debug for GenericBinaryArray<Offset
 }
 
 impl<OffsetSize: BinaryOffsetSizeTrait> Array for GenericBinaryArray<OffsetSize> {
-    fn as_any(&self) -> &Any {
+    fn as_any(&self) -> &dyn Any {
         self
     }
 
@@ -268,9 +270,80 @@ where
 }
 
 /// An array where each element is a byte whose maximum length is represented by a i32.
+///
+/// Examples
+///
+/// Create a BinaryArray from a vector of byte slices.
+///
+/// ```
+/// use arrow::array::{Array, BinaryArray};
+/// let values: Vec<&[u8]> =
+///     vec![b"one", b"two", b"", b"three"];
+/// let array = BinaryArray::from_vec(values);
+/// assert_eq!(4, array.len());
+/// assert_eq!(b"one", array.value(0));
+/// assert_eq!(b"two", array.value(1));
+/// assert_eq!(b"", array.value(2));
+/// assert_eq!(b"three", array.value(3));
+/// ```
+///
+/// Create a BinaryArray from a vector of Optional (null) byte slices.
+///
+/// ```
+/// use arrow::array::{Array, BinaryArray};
+/// let values: Vec<Option<&[u8]>> =
+///     vec![Some(b"one"), Some(b"two"), None, Some(b""), Some(b"three")];
+/// let array = BinaryArray::from_opt_vec(values);
+/// assert_eq!(5, array.len());
+/// assert_eq!(b"one", array.value(0));
+/// assert_eq!(b"two", array.value(1));
+/// assert_eq!(b"", array.value(3));
+/// assert_eq!(b"three", array.value(4));
+/// assert!(!array.is_null(0));
+/// assert!(!array.is_null(1));
+/// assert!(array.is_null(2));
+/// assert!(!array.is_null(3));
+/// assert!(!array.is_null(4));
+/// ```
+///
 pub type BinaryArray = GenericBinaryArray<i32>;
 
 /// An array where each element is a byte whose maximum length is represented by a i64.
+/// Examples
+///
+/// Create a LargeBinaryArray from a vector of byte slices.
+///
+/// ```
+/// use arrow::array::{Array, LargeBinaryArray};
+/// let values: Vec<&[u8]> =
+///     vec![b"one", b"two", b"", b"three"];
+/// let array = LargeBinaryArray::from_vec(values);
+/// assert_eq!(4, array.len());
+/// assert_eq!(b"one", array.value(0));
+/// assert_eq!(b"two", array.value(1));
+/// assert_eq!(b"", array.value(2));
+/// assert_eq!(b"three", array.value(3));
+/// ```
+///
+/// Create a LargeBinaryArray from a vector of Optional (null) byte slices.
+///
+/// ```
+/// use arrow::array::{Array, LargeBinaryArray};
+/// let values: Vec<Option<&[u8]>> =
+///     vec![Some(b"one"), Some(b"two"), None, Some(b""), Some(b"three")];
+/// let array = LargeBinaryArray::from_opt_vec(values);
+/// assert_eq!(5, array.len());
+/// assert_eq!(b"one", array.value(0));
+/// assert_eq!(b"two", array.value(1));
+/// assert_eq!(b"", array.value(3));
+/// assert_eq!(b"three", array.value(4));
+/// assert!(!array.is_null(0));
+/// assert!(!array.is_null(1));
+/// assert!(array.is_null(2));
+/// assert!(!array.is_null(3));
+/// assert!(!array.is_null(4));
+/// ```
+///
 pub type LargeBinaryArray = GenericBinaryArray<i64>;
 
 impl<'a, T: BinaryOffsetSizeTrait> IntoIterator for &'a GenericBinaryArray<T> {
@@ -582,7 +655,7 @@ impl fmt::Debug for FixedSizeBinaryArray {
 }
 
 impl Array for FixedSizeBinaryArray {
-    fn as_any(&self) -> &Any {
+    fn as_any(&self) -> &dyn Any {
         self
     }
 
@@ -671,12 +744,22 @@ impl DecimalArray {
 
     #[inline]
     pub fn value_as_string(&self, row: usize) -> String {
-        let decimal_string = self.value(row).to_string();
+        let value = self.value(row);
+        let value_str = value.to_string();
+
         if self.scale == 0 {
-            decimal_string
+            value_str
         } else {
-            let splits = decimal_string.split_at(decimal_string.len() - self.scale);
-            format!("{}.{}", splits.0, splits.1)
+            let (sign, rest) = value_str.split_at(if value >= 0 { 0 } else { 1 });
+
+            if rest.len() > self.scale {
+                // Decimal separator is in the middle of the string
+                let (whole, decimal) = value_str.split_at(value_str.len() - self.scale);
+                format!("{}.{}", whole, decimal)
+            } else {
+                // String has to be padded
+                format!("{}0.{:0>width$}", sign, rest, width = self.scale)
+            }
         }
     }
 
@@ -752,7 +835,7 @@ impl fmt::Debug for DecimalArray {
 }
 
 impl Array for DecimalArray {
-    fn as_any(&self) -> &Any {
+    fn as_any(&self) -> &dyn Any {
         self
     }
 
@@ -1167,6 +1250,23 @@ mod tests {
         assert_eq!(16, decimal_array.value_length());
     }
 
+    #[test]
+    fn test_decimal_array_value_as_string() {
+        let mut decimal_builder = DecimalBuilder::new(7, 5, 3);
+        for value in [123450, -123450, 100, -100, 10, -10, 0] {
+            decimal_builder.append_value(value).unwrap();
+        }
+        let arr = decimal_builder.finish();
+
+        assert_eq!("123.450", arr.value_as_string(0));
+        assert_eq!("-123.450", arr.value_as_string(1));
+        assert_eq!("0.100", arr.value_as_string(2));
+        assert_eq!("-0.100", arr.value_as_string(3));
+        assert_eq!("0.010", arr.value_as_string(4));
+        assert_eq!("-0.010", arr.value_as_string(5));
+        assert_eq!("0.000", arr.value_as_string(6));
+    }
+
     #[test]
     fn test_decimal_array_fmt_debug() {
         let values: Vec<i128> = vec![8887000000, -8887000000];
