@@ -219,39 +219,7 @@ impl PartialEq<StructArray> for Value {
     }
 }
 
-impl JsonEqual for MapArray {
-    fn equals_json(&self, json: &[&Value]) -> bool {
-        if self.len() != json.len() {
-            return false;
-        }
-
-        (0..self.len()).all(|i| match json[i] {
-            Value::Array(v) => self.is_valid(i) && self.value(i).equals_json_values(v),
-            Value::Null => self.is_null(i) || self.value_length(i).eq(&0),
-            _ => false,
-        })
-    }
-}
-
-impl PartialEq<Value> for MapArray {
-    fn eq(&self, json: &Value) -> bool {
-        match json {
-            Value::Array(json_array) => self.equals_json_values(json_array),
-            _ => false,
-        }
-    }
-}
-
-impl PartialEq<MapArray> for Value {
-    fn eq(&self, arrow: &MapArray) -> bool {
-        match self {
-            Value::Array(json_array) => arrow.equals_json_values(json_array),
-            _ => false,
-        }
-    }
-}
-
-impl<OffsetSize: OffsetSizeTrait> JsonEqual for GenericBinaryArray<OffsetSize> {
+impl<OffsetSize: BinaryOffsetSizeTrait> JsonEqual for GenericBinaryArray<OffsetSize> {
     fn equals_json(&self, json: &[&Value]) -> bool {
         if self.len() != json.len() {
             return false;
@@ -271,7 +239,9 @@ impl<OffsetSize: OffsetSizeTrait> JsonEqual for GenericBinaryArray<OffsetSize> {
     }
 }
 
-impl<OffsetSize: OffsetSizeTrait> PartialEq<Value> for GenericBinaryArray<OffsetSize> {
+impl<OffsetSize: BinaryOffsetSizeTrait> PartialEq<Value>
+    for GenericBinaryArray<OffsetSize>
+{
     fn eq(&self, json: &Value) -> bool {
         match json {
             Value::Array(json_array) => self.equals_json_values(json_array),
@@ -280,7 +250,9 @@ impl<OffsetSize: OffsetSizeTrait> PartialEq<Value> for GenericBinaryArray<Offset
     }
 }
 
-impl<OffsetSize: OffsetSizeTrait> PartialEq<GenericBinaryArray<OffsetSize>> for Value {
+impl<OffsetSize: BinaryOffsetSizeTrait> PartialEq<GenericBinaryArray<OffsetSize>>
+    for Value
+{
     fn eq(&self, arrow: &GenericBinaryArray<OffsetSize>) -> bool {
         match self {
             Value::Array(json_array) => arrow.equals_json_values(json_array),
@@ -289,7 +261,7 @@ impl<OffsetSize: OffsetSizeTrait> PartialEq<GenericBinaryArray<OffsetSize>> for
     }
 }
 
-impl<OffsetSize: OffsetSizeTrait> JsonEqual for GenericStringArray<OffsetSize> {
+impl<OffsetSize: StringOffsetSizeTrait> JsonEqual for GenericStringArray<OffsetSize> {
     fn equals_json(&self, json: &[&Value]) -> bool {
         if self.len() != json.len() {
             return false;
@@ -303,7 +275,9 @@ impl<OffsetSize: OffsetSizeTrait> JsonEqual for GenericStringArray<OffsetSize> {
     }
 }
 
-impl<OffsetSize: OffsetSizeTrait> PartialEq<Value> for GenericStringArray<OffsetSize> {
+impl<OffsetSize: StringOffsetSizeTrait> PartialEq<Value>
+    for GenericStringArray<OffsetSize>
+{
     fn eq(&self, json: &Value) -> bool {
         match json {
             Value::Array(json_array) => self.equals_json_values(json_array),
@@ -312,7 +286,9 @@ impl<OffsetSize: OffsetSizeTrait> PartialEq<Value> for GenericStringArray<Offset
     }
 }
 
-impl<OffsetSize: OffsetSizeTrait> PartialEq<GenericStringArray<OffsetSize>> for Value {
+impl<OffsetSize: StringOffsetSizeTrait> PartialEq<GenericStringArray<OffsetSize>>
+    for Value
+{
     fn eq(&self, arrow: &GenericStringArray<OffsetSize>) -> bool {
         match self {
             Value::Array(json_array) => arrow.equals_json_values(json_array),
@@ -433,12 +409,6 @@ impl PartialEq<Value> for NullArray {
     }
 }
 
-impl JsonEqual for ArrayRef {
-    fn equals_json(&self, json: &[&Value]) -> bool {
-        self.as_ref().equals_json(json)
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -929,11 +899,11 @@ mod tests {
     #[test]
     fn test_decimal_json_equal() {
         // Test the equal case
-        let arrow_array = [Some(1_000), None, Some(-250)]
-            .iter()
-            .collect::<DecimalArray>()
-            .with_precision_and_scale(23, 6)
-            .unwrap();
+        let mut builder = DecimalBuilder::new(30, 23, 6);
+        builder.append_value(1_000).unwrap();
+        builder.append_null().unwrap();
+        builder.append_value(-250).unwrap();
+        let arrow_array: DecimalArray = builder.finish();
         let json_array: Value = serde_json::from_str(
             r#"
             [
@@ -948,11 +918,10 @@ mod tests {
         assert!(json_array.eq(&arrow_array));
 
         // Test unequal case
-        let arrow_array = [Some(1_000), None, Some(55)]
-            .iter()
-            .collect::<DecimalArray>()
-            .with_precision_and_scale(23, 6)
-            .unwrap();
+        builder.append_value(1_000).unwrap();
+        builder.append_null().unwrap();
+        builder.append_value(55).unwrap();
+        let arrow_array: DecimalArray = builder.finish();
         let json_array: Value = serde_json::from_str(
             r#"
             [
